==> okteta-0.25.1.tar.xz: okteta-0.25.1/libs/kasten/gui/shell/abstractgroupedviews_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTGROUPEDVIEWS_P_H
#define ABSTRACTGROUPEDVIEWS_P_H

// lib
#include "abstractgroupedviews.h"
#include "abstractviewarea_p.h"

namespace Kasten {

class AbstractGroupedViewsPrivate : public AbstractViewAreaPrivate
{
public:
    explicit AbstractGroupedViewsPrivate(AbstractGroupedViews* parent);

    ~AbstractGroupedViewsPrivate() override;
};

inline AbstractGroupedViewsPrivate::AbstractGroupedViewsPrivate(AbstractGroupedViews* parent)
    : AbstractViewAreaPrivate(parent)
{
}

inline AbstractGroupedViewsPrivate::~AbstractGroupedViewsPrivate() = default;

}

#endif

==> okteta_4.13.0.orig.tar.xz: okteta-4.13.0/libs/kasten/gui/shell/abstractgroupedviews_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTGROUPEDVIEWS_P_H
#define ABSTRACTGROUPEDVIEWS_P_H

// lib
#include "abstractgroupedviews.h"
#include "abstractviewarea_p.h"


namespace Kasten2
{

class AbstractGroupedViewsPrivate : public AbstractViewAreaPrivate
{
  public:
    explicit AbstractGroupedViewsPrivate( AbstractGroupedViews* parent );

    virtual ~AbstractGroupedViewsPrivate();
};


inline AbstractGroupedViewsPrivate::AbstractGroupedViewsPrivate( AbstractGroupedViews* parent )
  : AbstractViewAreaPrivate( parent )
{
}

inline AbstractGroupedViewsPrivate::~AbstractGroupedViewsPrivate() {}

}

#endif
